-- ToME - Tales of Maj'Eyal
-- Copyright (C) 2009, 2010, 2011 Nicolas Casalini
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--




newTalent{
	name = "Summon Thugs",
	type = {"base/class", 1},
	points = 5,
	no_energy = true,
	cooldown = 60,
	tactical = { ATTACK = { PHYSICAL = 2 }, DISABLE = { stun = 1, knockback = 1 } },
	range = 0,
	action = function(self, t)
		local tg = {type="bolt", nowarning=true, range=self:getTalentRange(t), nolock=true, talent=t}
		local tx, ty = self.x, self.y
		
		-- Find space
		for i = 1, 2 do
			local x, y = util.findFreeGrid(tx, ty, 5, true, {[Map.ACTOR]=true})
			if not x then
				game.logPlayer(self, "Not enough space to summon!")
				return
			end

			local NPC = require "mod.class.NPC"
			local m = NPC.new{
				type = "humanoid", subtype = "human",
				display = "p",
				name = "Thug", color=colors.BLUE,
				desc = "A thug of the Assassin Lord.",
				level_range = {self.level, self.level}, exp_worth = 0,
				
				body = { INVEN = 10, MAINHAND=1, OFFHAND=1, BODY=1 },
				resolvers.drops{chance=0, nb=1, {} },
				resolvers.equip{
					{type="weapon", subtype="dagger", autoreq=true},
					{type="weapon", subtype="dagger", autoreq=true},
					{type="armor", subtype="light", autoreq=true}
				},
				infravision = 10,

				max_stamina = 300,
				rank = 2,
				size_category = 3,
				combat_armor = 3, combat_def = 10,
	
				
				resolvers.racial(),
				resolvers.sustains_at_birth(),

				open_door = true,

				--resolvers.inscriptions(1, "infusion"),
				resolvers.inscriptions(1, {"wild infusion", "healing infusion", "regeneration infusion", "movement infusion", "heroism infusion", "insidious poison infusion"}),

				autolevel = "rogue",
				ai = "summoned", ai_real = "dumb_talented_simple", ai_state = { ai_move="move_dmap", talent_in=5, },
				stats = { str=8, dex=15, mag=6, cun=15, con=7 },

				resolvers.talents{
					[Talents.T_DUAL_WEAPON_TRAINING]={base=2, every=6, max=6},
					[Talents.T_DUAL_WEAPON_DEFENSE]={base=2, every=6, max=6},
					[Talents.T_DUAL_STRIKE]={base=1, every=6, max=6},
					[Talents.T_LETHALITY]={base=5, every=6, max=8},
					[Talents.T_DISARM]={base=1, every=6, max=6},
					[Talents.T_TOTAL_THUGGERY]={base=1, every=5, max=7},
					[Talents.T_VICIOUS_STRIKES]={base=1, every=7, max=6},
					[Talents.T_SKULLCRACKER]={base=1, every=7, max=6},
				},

				--faction = self.faction,
				summon_time = 30,
				
			}
			m.no_inventory_access = true
			m.ai_state = m.ai_state or {}
			m.ai_state.tactic_leash = 5
			m:resolve() m:resolve(nil, true)
			m:forceLevelup(self.level)
			game.zone:addEntity(game.level, m, "actor", x, y)
			game.level.map:particleEmitter(x, y, 1, "summon")

			-- Summons never flee
			m.ai_tactic = m.ai_tactic or {}
			m.ai_tactic.escape = 0
			
			if self.money >= (0.2*m.level^2) then
				self:incMoney(-0.2*m.level^2)
				m.faction = self.faction
				m:doEmote(rng.table{
					"Who is giving you trouble, boss?",
					"Who needs a rough up?",
					"Trouble, boss?",
					"Time for some fun!",
					"Ready for some action!",
					"We will take care of it, boss.",
					"Who dares to oppose you?",
					"Just tell me who to kill.",
					"Ha, that will be an easy fight!",
					"They are no match for us!",
					"Just lean back and enjoy the show, boss.",
				}, 50)
				if game.party:hasMember(self) then
					local can_control = not no_controll

					m.remove_from_party_on_death = true
					game.party:addMember(m, {
						control="no",
						type="summon",
						title="Summon",
						orders = {target=true, leash=true, anchor=true, talents=false},
					})
					end
	
	
			else
				m.faction = "enemies"
				m:doEmote(rng.table{
					"What does that mean, you can't pay?",
					"Out of gold?!",
					"Next time you will think twice before calling us without being able to pay.",
					"We will show you what we do with someone who can't pay!",
					"Are you stupid? We don't work for free!",
				}, 75)
			end
			
		end

		game:playSoundNear(self, "talents/spell_generic")
		return true
	end,
	info = function(self, t)
		return ([[Summons 2 Thugs from the Assassin Lord to aid you.
		They expect to be paid %d gold for their service.]]):format(0.4*self.level^2)
	end,
}
